@@ -56,6 +56,16 @@ def bin2ascii(bins: str, replace=False, **kwargs) -> str:
     return chr(n)
 
 
+def txt2hex(txt: str, enc: str = "utf-8") -> str:
+    """Convertir le texte en héxadécimal dans l'encodage souhaité"""
+    return txt.encode(enc).hex(sep=" ").upper()
+
+
+def hex2txt(hex: str, enc: str = "utf-8") -> str:
+    """Convertir le code hexadécimal en texte l'encodage souhaité"""
+    return bytes.fromhex(hex).decode(enc)
+
+
 def bin2float(n: str, e: int = None, f: int = None, ieee: bool = False):
     """Décode un binaire flottant en flottant
 
